@@ -1,3 +1,7 @@
+#' @rdname REGE
+#' 
+#' @export
+
 REGE.for<-function(
     M, #netowrk in form of a matrix or array (in case of several relations)
    iter = 3,
@@ -18,8 +22,9 @@ REGE.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
   
-	E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(rege,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  E<-matrix(E,ncol=N, nrow=N)
+  diag(E)<-1.0
+  res<-.Fortran("rege",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -27,6 +32,9 @@ REGE.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
+#' @rdname REGE
+#' 
+#' @export
 
 REGD.for<-function(
    M, #netowrk in form of a matrix or array (in case of several relations)
@@ -48,8 +56,9 @@ REGD.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
   E<-matrix(as.double(E),ncol=N, nrow=N)
+  diag(E)<-1.0
 	
-	res<-.Fortran(regd,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+	res<-.Fortran("regd",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -58,6 +67,9 @@ REGD.for<-function(
 }
 
 
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.ow.for<-function(
    M, #netowrk in form of a matrix or array (in case of several relations)
@@ -79,7 +91,8 @@ REGE.ow.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
 	E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regeow,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+	diag(E)<-1.0
+  res<-.Fortran("regeow",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -87,6 +100,10 @@ REGE.ow.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
+#' @rdname REGE
+#' 
+#' @export
+
 REGD.ow.for<-function(
    M, #netowrk in form of a matrix or array (in case of several relations)
    iter = 3,
@@ -107,8 +124,9 @@ REGD.ow.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
   E<-matrix(as.double(E),ncol=N, nrow=N)
+  diag(E)<-1.0
 	
-  res<-.Fortran(regdow,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  res<-.Fortran("regdow",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -117,8 +135,9 @@ REGD.ow.for<-function(
 }
 
 
-
-
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.ownm.for<-function(
    M, #netowrk in form of a matrix or array (in case of two relations)
@@ -156,7 +175,8 @@ REGE.ownm.for<-function(
   }
 
   E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regeownm,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  diag(E)<-1.0
+  res<-.Fortran("regeownm",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -164,7 +184,9 @@ REGE.ownm.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
-
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.ownm.diag.for<-function(
    M, #netowrk in form of a matrix or array (in case of two relations)
@@ -202,7 +224,8 @@ REGE.ownm.diag.for<-function(
   }
 
   E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regeownmdiag,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  diag(E)<-1.0
+  res<-.Fortran("regeownmdiag",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -212,7 +235,9 @@ REGE.ownm.diag.for<-function(
 
 
 
-
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.nm.for<-function(
    M, #netowrk in form of a matrix or array (in case of two relations)
@@ -250,7 +275,8 @@ REGE.nm.for<-function(
   }
 
   E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regenm,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  diag(E)<-1.0
+  res<-.Fortran("regenm",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -258,6 +284,9 @@ REGE.nm.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.nm.diag.for<-function(
    M, #netowrk in form of a matrix or array (in case of two relations)
@@ -295,7 +324,8 @@ REGE.nm.diag.for<-function(
   }
 
   E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regenmdiag,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  diag(E)<-1.0
+  res<-.Fortran("regenmdiag",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -306,7 +336,9 @@ REGE.nm.diag.for<-function(
 
 
 
-
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.ne.for<-function(
     M, #netowrk in form of a matrix or array (in case of several relations)
@@ -329,7 +361,8 @@ REGE.ne.for<-function(
   dimnames(M)<-dnM
   
 	E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regene,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+	diag(E)<-1.0
+  res<-.Fortran("regene",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -337,6 +370,9 @@ REGE.ne.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.ow.ne.for<-function(
    M, #netowrk in form of a matrix or array (in case of several relations)
@@ -358,7 +394,8 @@ REGE.ow.ne.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
 	E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regeowne,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+	diag(E)<-1.0
+  res<-.Fortran("regeowne",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -366,6 +403,9 @@ REGE.ow.ne.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.ownm.ne.for<-function(
    M, #netowrk in form of a matrix or array (in case of two relations)
@@ -403,7 +443,8 @@ REGE.ownm.ne.for<-function(
   }
 
   E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regeownmne,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  diag(E)<-1.0
+  res<-.Fortran("regeownmne",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -413,7 +454,9 @@ REGE.ownm.ne.for<-function(
 
 
 
-
+#' @rdname REGE
+#' 
+#' @export
 
 REGE.nm.ne.for<-function(
    M, #netowrk in form of a matrix or array (in case of two relations)
@@ -451,7 +494,8 @@ REGE.nm.ne.for<-function(
   }
 
   E<-matrix(E,ncol=N, nrow=N)
-  res<-.Fortran(regenmne,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  diag(E)<-1.0
+  res<-.Fortran("regenmne",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -459,6 +503,9 @@ REGE.nm.ne.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
+#' @rdname REGE
+#' 
+#' @export
 
 REGD.ne.for<-function(
    M, #netowrk in form of a matrix or array (in case of several relations)
@@ -480,8 +527,9 @@ REGD.ne.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
   E<-matrix(as.double(E),ncol=N, nrow=N)
+  diag(E)<-1.0
 	
-	res<-.Fortran(regdne,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+	res<-.Fortran("regdne",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
@@ -489,7 +537,7 @@ REGD.ne.for<-function(
   return(list(E=Eall[,,"final"],Eall=Eall,M=M,iter=iter))
 }
 
-
+#' @rdname REGE
 
 REGD.ow.ne.for<-function(
    M, #netowrk in form of a matrix or array (in case of several relations)
@@ -511,8 +559,9 @@ REGD.ow.ne.for<-function(
   M<-structure(as.double(M),dim=dM)
   dimnames(M)<-dnM
   E<-matrix(as.double(E),ncol=N, nrow=N)
+  diag(E)<-1.0
 	
-  res<-.Fortran(regdowne,M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
+  res<-.Fortran("regdowne",M = M, E = E, N = as.integer(N), NR = as.integer(NR), iter = as.integer(iter))
   Eall<-array(NA,dim=c(dim(E),2))
   Eall[,,1]<-E
   Eall[,,2]<-res$E
